/*
 *     jsz.Plotter - a SWING-based Java package for plotting data
 * Copyright (C) 2000 Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: ControllerCaption.java,v 1.4 2000/02/03 21:01:22 schwarz Exp $
 */
package jsz.Plotter;

import java.awt.*;

/**
 * Example implementation of {@link jsz.Plotter.ITickInscription}.
 *
 * @author Janek Schwarz
 * @version 1.0
 */
public class ControllerCaption
  implements ITickCaption
{
/**
 * value which should represent the high-performance controller
 */
private double highPerformance;

/**
 * value which should represent the safety controller
 */
private double safety;

/**
 * value which should represent the baseline controller
 */
private double baseline;

/**
 * Constructs an object and assigns specific values to
 * high-performance, baseline and safety controller.
 *
 * @param highPerformance a value of type 'double'
 * @param baseline a value of type 'double'
 * @param safety a value of type 'double'
 */
public ControllerCaption(double highPerformance,
                         double baseline,
                         double safety)
{
  this.highPerformance = highPerformance;
  this.safety          = safety;
  this.baseline        = baseline;
}

/**
 * Marks the ticks, which correspond to high-performance,
 * baseline and safety controller. Any other tick is ignored.
 */
public String markTick(double value)
{
  if(value == highPerformance)
    return "H";
  else if(value == safety)
    return "S";
  else if(value == baseline)
    return "B";
  else                          // we dont mark any other ticks
    return "";
}
};
