/*
 *     jsz.Plotter - a Swing-based Java package for plotting data
 * Copyright (C) 2000  Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: ITickCaption.java,v 1.4 2000/02/03 21:01:28 schwarz Exp $
 */
package jsz.Plotter;

import java.awt.*;

/**
 * Using the ITickCaption interface a custom-made axis
 * caption can be implemented. When a plotter draws x- and
 * y-axis it calls the markTick() method for each tick it
 * marks. Have a look at the following example:
 * <pre>
 *    package jsz.Plotter;
 *    import java.awt.*;
 *
 *    public class ControllerCaption
 *      implements ITickCaption
 *    {
 *      private double highPerformance;
 *      private double safety;
 *      private double baseline;
 *
 *      public ControllerCaption(double highPerformance,
 *                                   double baseline,
 *                                   double safety)
 *      {
 *        this.highPerformance = highPerformance;
 *        this.safety          = safety;
 *        this.baseline        = baseline;
 *      }
 *
 *      public String markTick(double value)
 *      {
 *        if(value == highPerformance)
 *          return "H";
 *        else if(value == safety)
 *          return "S";
 *        else if(value == baseline)
 *          return "B";
 *        else                          // we dont mark any other tick
 *          return "";
 *      }
 *    };
 * </pre>
 *
 * @author Janek Schwarz 
 * @version 1.0
 */
public interface ITickCaption
{

/**
 * Mark a tick. For an example implementation see the example above.
 */ 
public String markTick(double value);
};
