/*
 *     jsz.Plotter - a Swing-based Java package for plotting data
 * Copyright (C) 2000  Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: LegendIcon.java,v 1.5 2000/02/03 21:01:30 schwarz Exp $
 */
package jsz.Plotter;

import javax.swing.*;
import java.awt.*;

/**
 * This class implements an icon for use with a {@link
 * jsz.Plotter.LegendLabel}. Usually, the icon is just
 * a short line drawn with the default color of the dataseries it
 * is associated with. Anyway, it is possible to specify a
 * different color as well.
 */ 
public class LegendIcon
  implements Icon
{
/**
 * Associated dataseries. Might be null.
 */
private IDataSeries ds = null;

/**
 * Length of the line
 */
private int length = 10;

/**
 * Height of the line (ignored at the moment).
 */
private int height = 1;

/**
 * Color. this color overwrites the color of ds!
 */
private Color color = null;

/**
 * Construct an icon with the default color from ds.
 */
public LegendIcon(IDataSeries ds)
{
  this.ds = ds;
}

/**
 * Construct an icon using color c.
 */
public LegendIcon(Color color)
{
  this.color = color;
}

/*
 * see javax.swing.Icon
 */
public void paintIcon(Component c,
                      Graphics g,
                      int x,
                      int y)
{
  Color orgColor = g.getColor();

  if(color != null)
    g.setColor(color);
  else
    g.setColor(ds.getColor());

  g.drawLine(x, y, x + length, y);
  g.setColor(orgColor);
}

/*
 * see javax.swing.Icon
 */
public final int getIconWidth()
{
  return length;
}

/*
 * see javax.swing.Icon
 */
public final int getIconHeight()
{
  return height;
}
};
