/*
 *     jsz.Plotter - a Swing-based Java package for plotting data
 * Copyright (C) 2000  Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: LegendLabel.java,v 1.4 2000/02/03 21:01:32 schwarz Exp $
 */
package jsz.Plotter;

import javax.swing.*;
import java.awt.*;
import java.util.*;

/**
 * This class implements the legend for plot (graphical
 * representation of a {@link
 * jsz.Plotter.DataSeries}. A legend is simply a
 * JLabel, which uses a {@link jsz.Plotter.LegendIcon}
 * as its icon. Using a JLabel has the advantage of absolut
 * freedom of arranging the legends. You simply take a JPanel,
 * use the LayoutManager which suits best and add the
 * legends. Anyway, there is {@link jsz.Plotter.LegendPanel}
 * for your convinience, which lets you add {@link
 * jsz.Plotter.IDataSeries} objects, so you dont have
 * to instantiate the labels yourself.
 */
public class LegendLabel
  extends JLabel
  implements Observer
{

/**
 * Creates a label and adds this instance to ds's observer list.
 */ 
public LegendLabel(IDataSeries ds)
{
  this.setIcon(new LegendIcon(ds));
  this.setText(ds.getLegend());
  
  ds.addObserver(this);
}

/**
 * Creates a label with icon and text. No Observer
 * functionality in this case. 
 */ 
public LegendLabel(LegendIcon icon, String legend)
{
  this.setIcon(icon);
  this.setText(legend);
}

/*
 * for implementing the Observer interface. 
 * gets called by an Observable object, which notifies it's Observers about 
 * a change.
 */ 
public void update(Observable o,
                   Object arg)
{ 
  if(arg != null)
    {
      UpdateDescription reason = (UpdateDescription) arg;
  
      if(reason.reason == UpdateDescription.ALL ||
         reason.reason == UpdateDescription.LEGEND ||
         reason.reason == UpdateDescription.GRAPH_COLOR)
        {
          IDataSeries ds = (IDataSeries) reason.obj;
          
          this.setText(ds.getLegend());
          this.setIcon(new LegendIcon(ds));
          
          this.invalidate();
          this.validate();
        }
    }
  else
    System.err.println(
      "LegendLabel.update() called without argument. What shall I do?");
}
};
