/*
 *     jsz.Plotter - a Swing-based Java package for plotting data
 * Copyright (C) 2000  Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: MaximaCaption.java,v 1.4 2000/02/03 21:01:36 schwarz Exp $
 */
package jsz.Plotter;

/**
 * This is an caption class, which marks only the maxima
 * values of an axis. 
 *
 * @see jsz.Plotter.ITickCaption
 * @author Janek Schwarz
 * @version 1.0
 */ 
class MaximaCaption
  implements ITickCaption
{
private Plotter plotter;
private boolean horizontal;
private boolean vertical;

/**
 * constructor.
 *
 * @param plotter reference to the plotter, which axis are
 * marked. This is needed because the maximum values of a
 * plotter can change during runtime.  
 * @param horizontal true: mark x-axis; false: mark y-axis
 */
public MaximaCaption(Plotter plotter,
                         boolean horizontal)
{
  this.plotter      = plotter;
  this.horizontal   = horizontal;
  this.vertical     = !horizontal;
}


/**
 * Mark the ticks which coresspond to the maximum values.
 *
 * @param value a value of type 'double'
 * @return its corresponding caption
 */
public String markTick(double value)
{
  String s;
  
  if(horizontal && value == plotter.getXMin())
    s = new Double(value).toString();
  else if(horizontal && value == plotter.getXMax())
    s = new Double(value).toString();
  else if(vertical && value == plotter.getYMin())
    s = new Double(value).toString();
  else if(vertical && value == plotter.getYMax())
    s = new Double(value).toString();
  else
    s = "";

  return s;
}
};
