/*
 *     jsz.Plotter - a Swing-based Java package for plotting data
 * Copyright (C) 2000  Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: PlotterTest2.java,v 1.4 2000/02/03 21:01:41 schwarz Exp $
 */
package jsz.Plotter;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/*
 * This class demonstrates some features of the
 * jsz.Plotter package:
 *    it respects the current look and feel; here: system look & feel
 *    custom-made axis caption (y-axis)
 *    'Observer' functionality: when the color of ds changes,
 *                              everything which refers to ds
 *                              (plotter, legend) changes too.
 */
public class PlotterTest2
{
public static void main(String argv[]) 
{
  try 
    {
      UIManager.setLookAndFeel(
        UIManager.getSystemLookAndFeelClassName());
    } 
  catch (Exception e) 
    {}

  JFrame frame = new JFrame("PlotterTest");
  LegendPanel legendpanel = new LegendPanel();
  legendpanel.setBorder(BorderFactory.createTitledBorder(
    BorderFactory.createEtchedBorder(), "Legend"));
  ((FlowLayout)legendpanel.getLayout()).setHgap(20);
  
  Plotter plotter = new Plotter(-5.0, // xmin
                                5.0, // xmax
                                -1.0, // ymin
                                3.0, // ymax
                                1.0, // xTicksDistance
                                1.0); // yTicksDistance
  plotter.setBorder(BorderFactory.createTitledBorder(
    BorderFactory.createEtchedBorder(), "Plotter Test"));
  plotter.setSize(new Dimension(200, 200));

  plotter.setTicksAsDottedLines(true);
  plotter.setXticksCaptionStyle(Plotter.MAXIMA_ZERO);
  plotter.setYticksCaptionStyle(Plotter.OBJECT);
  plotter.setYticksCaptionObject(
    new ControllerCaption(3.0, 2.0, 1.0));
  
  plotter.setXaxisBehaviour(Plotter.FIT);
  
  IDataSeries ds  = new DataSeries("Plot 1", Color.black);
  IDataSeries ds2 = new DataSeries("Plot 2", Color.red);
  IDataSeries ds3 = new DataSeries("Plot 3", Color.green);

  plotter.addPlot(ds).addPlot(ds2).addPlot(ds3);
  legendpanel.addPlot(ds).addPlot(ds2).addPlot(ds3);
   
  frame.getContentPane().setLayout(new BorderLayout()); 
  Box box = Box.createVerticalBox();
  box.add(plotter, BorderLayout.CENTER);
  box.add(legendpanel, BorderLayout.SOUTH);
  frame.getContentPane().add(box, BorderLayout.CENTER);

  frame.addWindowListener(new WindowAdapter() {
    public void windowClosing(WindowEvent e) {
      System.exit(0);
    }
    });
  frame.pack();
  frame.setVisible(true);

  for(double i = -5; ; i += .5)
    {
      if(i == 0.0)
        ds.setColor(Color.yellow);
      
      ds.addDataSet(i, 3);
      ds2.addDataSet(i, 2);
      ds3.addDataSet(i, 1);

      try
        {
          Thread.sleep(500);
        }
      catch(Exception ex)
        {
        }
    }
}
};
